/*
 *
 * This file is a part of the CaosDB Project.
 *
 * Copyright (C) 2021 Florian Spreckelsen <f.spreckelsen@indiscale.com>
 * Copyright (C) 2021 IndiScale GmbH <info@indiscale.com>
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public
 * License along with this program. If not, see
 * <https://www.gnu.org/licenses/>.
 *
 */
#include <string>

#include <jlcxx/jlcxx.hpp>

#include "caosdb/authentication.h"
#include "caosdb/connection.h"
#include "caosdb/constants.h"
#include "caosdb/exceptions.h"

JLCXX_MODULE define_julia_module(jlcxx::Module& mod)
{
  // Version info of libcaosdb against which this is built.
  mod.method("get_libcaosdb_version_major", []() {return caosdb::LIBCAOSDB_VERSION_MAJOR;});
  mod.method("get_libcaosdb_version_minor", []() {return caosdb::LIBCAOSDB_VERSION_MINOR;});
  mod.method("get_libcaosdb_version_patch", []() {return caosdb::LIBCAOSDB_VERSION_PATCH;});

  // exceptions inherit from abstract Julia exception types:
  mod.add_type<caosdb::exceptions::AuthenticationError>("AuthenticationError", jlcxx::julia_type("AbstractAuthenticationError"))
    .constructor<const std::string&>()
    .method("what", &caosdb::exceptions::AuthenticationError::what);
  mod.add_type<caosdb::exceptions::ConnectionError>("ConnectionError", jlcxx::julia_type("AbstractConnectionError"))
    .constructor<const std::string&>()
    .method("what", &caosdb::exceptions::ConnectionError::what);
}
